import React, { useState } from 'react';
import { Image, Upload } from 'antd';
import { LoadingOutlined, PlusOutlined, CloseOutlined } from '@ant-design/icons';
import type { GetProp, UploadProps } from 'antd';
import styles from './index.less';

interface IFormUpload {
  value?: string;
  onChange?: (val: string) => void;
}
type FileType = Parameters<GetProp<UploadProps, 'beforeUpload'>>[0];

const getBase64 = (img: FileType, callback: (url: string) => void) => {
  const reader = new FileReader();
  reader.addEventListener('load', () => callback(reader.result as string));
  reader.readAsDataURL(img);
};

const FormUpload: React.FC<IFormUpload> = ({ onChange }) => {
  const [loading, setLoading] = useState(false);
  const [imageUrl, setImageUrl] = useState('');

  const handleUpload = async (info: any) => {
    if (info.file.status === 'uploading') {
      setLoading(true);
      return;
    }
    if (info.file.status === 'done') {
      getBase64(info.file.originFileObj as FileType, (url) => {
        setLoading(false);
        setImageUrl(url);
      });
    }
    onChange?.(info);
  };

  const uploadButton = (
    <button style={{ border: 0, background: 'none' }} type="button">
      {loading ? <LoadingOutlined /> : <PlusOutlined />}
      <div style={{ marginTop: 8 }}>上传图片</div>
    </button>
  );

  return (
    <>
      {imageUrl ? (
        <div className={styles.bannerItem}>
          <Image width="100%" height="100%" src={imageUrl} />
          <div className={styles.operation} onClick={() => setImageUrl('')}>
            <CloseOutlined />
          </div>
        </div>
      ) : (
        <Upload
          accept=".png,.jpg,.jpeg,.gif,.webp,.svg"
          name="file"
          listType="picture-circle"
          className={`avatar-uploader uploadBtn`}
          showUploadList={false}
          onChange={handleUpload}
        >
          {uploadButton}
        </Upload>
      )}
    </>
  );
};

export default FormUpload;
