import React, { useState, useEffect, memo } from 'react';
import { Image, Popconfirm, Table, Button, Modal, Form, Input } from 'antd';
import type { TableColumnsType } from 'antd';
import FormUpload from './Upload';
import styles from './index.less';

interface IItemImage {
  id: number;
  url: string;
  path?: string;
}

type FieldType = {
  file?: string;
  path?: string;
};

export interface IBanner {
  type: number;
  dataSource: IItemImage[];
  onChange: (fileInfo: any, params: { type: number; path: string }) => void;
  onDelFile: (id: number) => void;
}

const Banner: React.FC<IBanner> = ({ type, dataSource, onChange, onDelFile }) => {
  const [dataList, setDataList] = useState<IItemImage[]>(dataSource);
  const [open, setOpen] = useState<boolean>();
  const [form] = Form.useForm();

  useEffect(() => {
    setDataList(dataSource);
  }, [dataSource]);

  const columns: TableColumnsType = [
    {
      title: '图片',
      dataIndex: 'url',
      width: '300px',
      render: (_: any, record: any) => {
        return (
          <>
            <Image width={180} height={100} src={record.url} />
          </>
        );
      },
    },
    {
      title: '跳转链接',
      align: 'center',
      dataIndex: 'path',
    },
    {
      title: '上传时间',
      align: 'center',
      dataIndex: 'createTime',
      width: 200,
    },
    {
      title: '操作',
      width: 80,
      align: 'center',
      dataIndex: 'operation',
      render: (_: any, record: any) =>
        dataSource.length >= 1 ? (
          <Popconfirm
            title="Sure to delete?"
            onConfirm={() => onDelFile((record as IItemImage).id)}
          >
            <a>删除</a>
          </Popconfirm>
        ) : null,
    },
  ];

  const handleOk = () => {
    const { file, path } = form.getFieldsValue() || {};
    onChange?.(file, {
      type,
      path,
    });
    setOpen(false);
  };

  return (
    <>
      <div className={styles.header}>
        <Button type="primary" onClick={() => setOpen(true)}>
          新增
        </Button>
      </div>
      <Modal
        title="新增数据"
        open={open}
        centered
        width={600}
        okText="提交"
        cancelText="取消"
        onOk={handleOk}
        onCancel={() => setOpen(false)}
        destroyOnClose
      >
        <Form
          name="basic"
          labelCol={{ span: 4 }}
          wrapperCol={{ span: 16 }}
          style={{ maxWidth: 600 }}
          autoComplete="off"
          form={form}
        >
          <Form.Item<FieldType>
            label="图片"
            name="file"
            rules={[{ required: true, message: 'Please input your username!' }]}
          >
            <FormUpload />
          </Form.Item>

          <Form.Item<FieldType> label="跳转链接" name="path">
            <Input />
          </Form.Item>
        </Form>
      </Modal>
      <Table bordered dataSource={dataList} columns={columns} rowClassName="editable-row" />
    </>
  );
};

export default memo(Banner);
