import { PageContainer } from '@ant-design/pro-components';
import { useModel } from '@umijs/max';
import { Card } from 'antd';
import React, { useState } from 'react';
import { getUserList, updateUser, deleteUser } from '@/services/ant-design-pro/api';
import { EditableProTable } from '@ant-design/pro-components';
import type { ProColumns } from '@ant-design/pro-components';
import { bankList } from '@/constant';

interface DataSourceType {
  id: string;
  phone: string;
  email: string;
  username: string;
}

const Welcome: React.FC = () => {
  const { initialState } = useModel('@@initialState');
  const [editableKeys, setEditableRowKeys] = useState<React.Key[]>([]);
  const [dataSource, setDataSource] = useState<readonly DataSourceType[]>([]);

  const request = async () => {
    const result = await getUserList();
    let data = [];
    if (result.code === 0) {
      data = result.data;
    } else {
      data = [];
    }
    return {
      data,
      total: 3,
      success: true,
    };
  };

  const columns: ProColumns[] = [
    {
      title: '用户名',
      dataIndex: 'username',
      key: 'username',
      // 第一行不允许编辑
      editable: (text, record, index) => {
        return index !== 0;
      },
    },
    {
      title: '电话',
      dataIndex: 'phone',
      key: 'phone',
    },
    {
      title: '邮箱',
      dataIndex: 'email',
      key: 'email',
    },
    {
      title: '银行',
      dataIndex: 'type',
      key: 'type',
      editable: (text, record, index) => {
        return index !== 0;
      },
      render: (_, record) => {
        const bank = bankList.find((item) => item.id === record.type);
        return <>{bank?.name}</>;
      },
    },
    {
      title: '操作',
      valueType: 'option',
      width: 200,
      render: (text, record, _, action) => [
        <a
          key="editable"
          onClick={() => {
            action?.startEditable?.(record.id);
          }}
        >
          编辑
        </a>,
        <a
          key="delete"
          onClick={() => {
            deleteUser(record);
            setDataSource(dataSource.filter((item) => item.id !== record.id));
          }}
        >
          删除
        </a>,
      ],
    },
  ];
  return (
    <PageContainer>
      <Card
        style={{
          borderRadius: 8,
        }}
        bodyStyle={{
          backgroundImage:
            initialState?.settings?.navTheme === 'realDark'
              ? 'background-image: linear-gradient(75deg, #1A1B1F 0%, #191C1F 100%)'
              : 'background-image: linear-gradient(75deg, #FBFDFF 0%, #F5F7FF 100%)',
        }}
      >
        <EditableProTable<DataSourceType>
          rowKey="id"
          maxLength={5}
          scroll={{
            x: 960,
          }}
          loading={false}
          columns={columns}
          request={request}
          value={dataSource}
          onChange={setDataSource}
          editable={{
            type: 'multiple',
            editableKeys,
            onSave: async (rowKey, data, row) => {
              console.log(rowKey, data, row);
              const newData = {
                id: data.id,
                email: data.email,
                phone: data.phone,
              };
              updateUser(newData);
            },
            onChange: setEditableRowKeys,
          }}
        />
      </Card>
    </PageContainer>
  );
};

export default Welcome;
